# Quantinuum schemas

Public models that define API boundaries used by Quantinuum.  Intended to be
used across teams and projects ie. shared. Backwards compatibility and semantic
versioning are particularly important in this repo!

## Dependencies

We try to keep the dependencies minimal.
However we do need `pydantic` for validation and `pytket` for core (serialisable) models.
